
# Slot: predicate




URI: [biolink:anatomical_entity_to_anatomical_entity_part_of_association_predicate](https://w3id.org/biolink/vocab/anatomical_entity_to_anatomical_entity_part_of_association_predicate)


## Domain and Range

[AnatomicalEntityToAnatomicalEntityPartOfAssociation](AnatomicalEntityToAnatomicalEntityPartOfAssociation.md) &#8594;  <sub>1..1</sub> [PredicateType](types/PredicateType.md)

## Parents

 *  is_a: [predicate](predicate.md)

## Children


## Used by

 * [AnatomicalEntityToAnatomicalEntityPartOfAssociation](AnatomicalEntityToAnatomicalEntityPartOfAssociation.md)
